@@ -4,7 +4,9 @@
 
 from gestures import *
 from marionette import Marionette, HTMLElement, Actions, MultiActions
-from marionette_test import MarionetteTestCase, CommonTestCase
+from marionette_test import MarionetteTestCase, CommonTestCase, expectedFailure, skip, SkipTest
 from emulator import Emulator
+from runtests import MarionetteTestResult
 from runtests import MarionetteTestRunner
 from runtests import MarionetteTestOptions
+from runtests import MarionetteTextTestRunner
