@@ -3,9 +3,11 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import datetime
+import os
 import socket
 import sys
 import time
+import traceback
 
 from client import MarionetteClient
 from application_cache import ApplicationCache
@@ -584,7 +586,7 @@ class Marionette(object):
 
         return unwrapped
 
-    def execute_js_script(self, script, script_args=None, async=True, new_sandbox=True, special_powers=False, script_timeout=None):
+    def execute_js_script(self, script, script_args=None, async=True, new_sandbox=True, special_powers=False, script_timeout=None, filename=None):
         if script_args is None:
             script_args = []
         args = self.wrapArguments(script_args)
@@ -594,34 +596,44 @@ class Marionette(object):
                                       args=args,
                                       async=async,
                                       newSandbox=new_sandbox,
-                                      specialPowers=special_powers, 
-                                      scriptTimeout=script_timeout)
+                                      specialPowers=special_powers,
+                                      scriptTimeout=script_timeout,
+                                      filename=filename,
+                                      line=None)
         return self.unwrapValue(response)
 
     def execute_script(self, script, script_args=None, new_sandbox=True, special_powers=False, script_timeout=None):
         if script_args is None:
             script_args = []
         args = self.wrapArguments(script_args)
+        stack = traceback.extract_stack()
+        frame = stack[-2:-1][0] # grab the second-to-last frame
         response = self._send_message('executeScript',
-                                     'value',
+                                      'value',
                                       value=script,
                                       args=args,
                                       newSandbox=new_sandbox,
                                       specialPowers=special_powers,
-                                      scriptTimeout=script_timeout)
+                                      scriptTimeout=script_timeout,
+                                      line=int(frame[1]),
+                                      filename=os.path.basename(frame[0]))
         return self.unwrapValue(response)
 
     def execute_async_script(self, script, script_args=None, new_sandbox=True, special_powers=False, script_timeout=None):
         if script_args is None:
             script_args = []
         args = self.wrapArguments(script_args)
+        stack = traceback.extract_stack()
+        frame = stack[-2:-1][0] # grab the second-to-last frame
         response = self._send_message('executeAsyncScript',
                                       'value',
                                       value=script,
                                       args=args,
                                       newSandbox=new_sandbox,
                                       specialPowers=special_powers,
-                                      scriptTimeout=script_timeout)
+                                      scriptTimeout=script_timeout,
+                                      line=int(frame[1]),
+                                      filename=os.path.basename(frame[0]))
         return self.unwrapValue(response)
 
     def find_element(self, method, target, id=None):
